import 'package:dio/dio.dart';

import '../resources.dart';
import 'models/language_available.dart';

class MyAppEndpoint {
  MyAppEndpoint._();
  static String getLanguageAvailableByKeyword() =>
      "v2/ooh/getLanguageAvailableByKeyword";
  static String getLanguagesOfCountry() => "v2/country/getLanguagesOfCountry";
}

abstract class MyAppApi {
  Future<NetworkResponse> getLanguageAvailableByKeyword(params);
  Future<NetworkResponse> getLanguagesOfCountry(params);
}

class MyAppApiImp extends MyAppApi {
  @override
  Future<NetworkResponse> getLanguageAvailableByKeyword(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(requiredToken: false).get(
          MyAppEndpoint.getLanguageAvailableByKeyword(),
          queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => LanguageAvailable.fromJson(e)).toList(),
      );
    } on DioException catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getLanguagesOfCountry(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(requiredToken: false)
          .get(MyAppEndpoint.getLanguagesOfCountry(), queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => LanguageAvailable.fromJson(e)).toList(),
      );
    } on DioException catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }
}
