import 'package:_private_core/_private_core.dart';

import '../common/models/file_upload_result.dart';
import '../payment/models/payment_billing_info.dart';
import '_model.dart';

class UserModel {
  int? id;
  String? firebaseId;
  String? username;
  String? tokenFirebase;
  String? token;
  String? uniqueId;
  String? firstName;
  String? lastName;
  String? displayName;
  String? infoName;
  String? phone;
  String? email;
  String? comment;
  String? thumbnail;
  int? blurPicture;
  int? reliability;
  int? createdAt;
  int? signedAt;
  int? allowGeolocation;
  List? fCMTokens;
  int? isTmpEmail;
  int? sellerStatus;
  String? sellerQrCode;
  int? timeBeforeStartTracking;
  dynamic distanceBeforeStartTracking;
  String? interfaceLanguageCode;
  String? dateFormat;
  String? timeFormat;
  List<PaymentBillingInfo>? billingInfos;
  TokenResponseLoginMqtt? mqtt;
  int? status;
  String? aboutMeHomelido;
  int? isTmp;
  FileUploadResult? banner;
  dynamic rating;

  bool get isUserVersion => true;

  String get fChar => displayName == null || displayName!.isEmpty
      ? ''
      : displayName!.split('').first;

  bool isNotYetSeller([int? status]) {
    status ??= sellerStatus;
    return status != SELLER_STATUS_WAIT_PASSPORT &&
        status != SELLER_STATUS_WAIT_SELFIE &&
        status != SELLER_STATUS_WAIT_REQUEST &&
        status != SELLER_STATUS_WAIT_APPROVE &&
        status != SELLER_STATUS_IS_SELLER &&
        status != SELLER_STATUS_HAS_QUIT_TMP &&
        status != SELLER_STATUS_HAS_QUIT_FOREVER &&
        status != SELLER_STATUS_IS_REJECTED;
  }

  UserModel({
    this.id,
    this.firebaseId,
    this.username,
    this.tokenFirebase,
    this.token,
    this.uniqueId,
    this.firstName,
    this.lastName,
    this.displayName,
    this.infoName,
    this.phone,
    this.email,
    this.comment,
    this.thumbnail = '',
    this.blurPicture = 0,
    this.reliability = 0,
    this.createdAt = 0,
    this.allowGeolocation = 0,
    this.signedAt = 0,
    this.fCMTokens,
    this.isTmpEmail,
    this.sellerStatus,
    this.sellerQrCode,
    this.timeBeforeStartTracking = 0,
    this.interfaceLanguageCode,
    this.distanceBeforeStartTracking,
    this.dateFormat,
    this.timeFormat,
    this.billingInfos,
    this.mqtt,
    this.aboutMeHomelido,
    this.isTmp,
    this.status,
    this.banner,
    this.rating,
  });

  UserModel.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    firebaseId = json['firebaseId'] ?? '';
    username = json['username'] ?? '';
    tokenFirebase = json['tokenFirebase'];
    token = json['token'];
    uniqueId = json['uniqueId'];
    firstName = json['firstName'] ?? '';
    lastName = json['lastName'] ?? '';
    displayName = json['displayName'] ?? '';
    infoName = json['infoName'] ?? '';
    phone = json['phone'] ?? '';
    email = json['email'];
    comment = json['comment'];
    thumbnail = json['thumbnail'] ?? '';
    blurPicture = json['blurPicture'];
    reliability = json['reliability'];
    createdAt = json['createdAt'];
    signedAt = json['signedAt'];
    fCMTokens = json['fcmToken'];
    allowGeolocation = json['allowGeolocation'];
    isTmpEmail = json['isTmpEmail'];
    sellerStatus = json['sellerStatus'];
    sellerQrCode = json['sellerQrCode'] ?? "";
    timeBeforeStartTracking = json['timeBeforeStartTracking'] ?? 0;
    interfaceLanguageCode = json['interfaceLanguageCode'];
    distanceBeforeStartTracking = json['distanceBeforeStartTracking'] ?? 0.0;
    dateFormat = json['dateFormat'];
    timeFormat = json['timeFormat'];
    if (json["billingInfos"] is List) {
      billingInfos = (json["billingInfos"] as List)
          .map((e) => PaymentBillingInfo.fromJson(e))
          .toList();
    }

    mqtt = json["mqtt"] == null
        ? null
        : TokenResponseLoginMqtt.fromJson(json["mqtt"]);
    isTmp = json["isTmp"];
    aboutMeHomelido = json["aboutMeHomelido"];
    status = json["status"];
    if (json["banner"] != null) {
      banner = FileUploadResult.fromJson(json["banner"]);
    } 
    if (json["rating"] is num) {
      rating = json["rating"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = id;
    data['firebaseId'] = firebaseId;
    data['username'] = username;
    data['tokenFirebase'] = tokenFirebase;
    data['token'] = token;
    data['uniqueId'] = uniqueId;
    data['firstName'] = firstName;
    data['lastName'] = lastName;
    data['displayName'] = displayName;
    data['infoName'] = infoName;
    data['phone'] = phone;
    data['email'] = email;
    data['comment'] = comment;
    data['thumbnail'] = thumbnail;
    data['blurPicture'] = blurPicture;
    data['reliability'] = reliability;
    data['createdAt'] = createdAt;
    data['signedAt'] = signedAt;
    data['allowGeolocation'] = allowGeolocation;
    data['isTmpEmail'] = isTmpEmail;
    data['sellerStatus'] = sellerStatus;
    data['sellerQrCode'] = sellerQrCode;
    data['timeBeforeStartTracking'] = timeBeforeStartTracking;
    data['interfaceLanguageCode'] = interfaceLanguageCode;
    data['distanceBeforeStartTracking'] = distanceBeforeStartTracking;
    data['dateFormat'] = dateFormat;
    data['timeFormat'] = timeFormat;
    data["aboutMeHomelido"] = aboutMeHomelido;
    data["status"] = status;
    data["rating"] = rating;
    data["isTmp"] = isTmp;
     data["banner"] = banner?.toJson();
    return data;
  }

  Map<String, dynamic> toJsonSqlite() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['uniqueId'] = uniqueId;
    data['firstName'] = firstName;
    data['lastName'] = lastName;
    data['id'] = id;
    data['displayName'] = displayName;
    data['firebaseId'] = firebaseId;
    data['username'] = username;
    data['thumbnail'] = thumbnail;
    return data;
  }
}

class GetUserDetailModel {
  GetUserDetailModel({
    required this.userInfo,
  });

  UserModel userInfo;

  factory GetUserDetailModel.fromJson(Map<String, dynamic> json) =>
      GetUserDetailModel(
        userInfo: UserModel.fromJson(json["values"]),
      );

  Map<String, dynamic> toJson() => {
        "values": userInfo.toJson(),
      };
}
