import 'package:_private_core/_private_core.dart';
import '../resources.dart';

class BarsRestaurantsRepo {
  BarsRestaurantsRepo._();

  static BarsRestaurantsRepo? _instance;

  factory BarsRestaurantsRepo([AppApi? api]) {
    _instance ??= BarsRestaurantsRepo._();
    _instance!._api = api ?? AppApiImp();
    return _instance!;
  }

  late AppApi _api;

  Future<String?> updateFilterValueForOobr(
      oobrPlaceId, filterId, value, lat, lng) async {
    NetworkResponse response = await _api.updateFilterValueForOobr({
      'lat': lat,
      'lng': lng,
      'value': value,
      'filterId': filterId,
      'oobrPlaceId': oobrPlaceId
    });
    return response.data;
  }

  Future<List<BrPlaceModel>> getOoBRPlacesAroundMe(lat, lng,
      [distance = 100000]) async {
    NetworkResponse response = await _api
        .getOoBRPlacesAroundMe({'lat': lat, 'lng': lng, 'distance': distance});
    return response.data ?? [];
  }

  Future<List<BrPlaceModel>> getOoBRPlacesByFilterValues(
      {lat,
      lng,
      languageCode,
      filters,
      globalNote,
      catLanguageCode,
      distance = 100000}) async {
    Map<String, dynamic> params = {
      'lat': lat,
      'lng': lng,
      'distance': distance,
      'languageCode': languageCode,
    };
    if (globalNote != null) params.addAll({'globalNote': globalNote});
    if (catLanguageCode != null)
      params.addAll({'catLanguageCode': catLanguageCode});
    if (filters != null) params.addAll({'filters': filters});
    NetworkResponse response = await _api.getOoBRPlacesByFilterValues(params);
    return response.data ?? [];
  }

  Future<List<BrPlaceModel>> getFavoriteOobrPlaces() async {
    NetworkResponse response = await _api.getFavoriteOobrPlaces();
    return response.data ?? [];
  }

  Future<List<String>> getPromotedVideosForBar(oobrPlaceId) async {
    NetworkResponse response = await _api.getPromotedVideosForBar(oobrPlaceId);
    return response.data ?? [];
  }

  Future<List<BrPromotedVideoModel>> getPromotedVideosForOobrPlaces(
      {lat, lng}) async {
    NetworkResponse response =
        await _api.getPromotedVideosForOobrPlaces(lat, lng);
    return response.data ?? [];
  }

  Future<BrPlaceModel?> getOoBRPlaceInfoById(oobrPlaceId) async {
    NetworkResponse response =
        await _api.getOoBRPlaceInfoById({'oobrPlaceId': oobrPlaceId});
    return response.data;
  }

  Future<BrPlaceMenuContent?> getOobrPlaceMenuContent(oobrPlaceId) async {
    NetworkResponse response =
        await _api.getOobrPlaceMenuContent(oobrPlaceId, appPrefs.languageCode);
    return response.data;
  }

  Future<List<BrPlaceCateModel>> getOoBRCategories() async {
    NetworkResponse response =
        await _api.getOoBRCategories(appPrefs.languageCode);
    return response.data ?? [];
  }

  Future<List<BrPlaceFilterModel>> getOoBRFilters() async {
    NetworkResponse response = await _api.getOoBRFilters(appPrefs.languageCode);
    return response.data ?? [];
  }

  Future<String?> checkBarGooglePlaceIdByContributor(googlePlaceId) async {
    NetworkResponse response =
        await _api.checkBarGooglePlaceIdByContributor(googlePlaceId);
    return response.data;
  }

  Future<bool> createNewOobrPlaceByContributor(params) async {
    NetworkResponse response =
        await _api.createNewOobrPlaceByContributor(params);
    return response.data ?? false;
  }

  Future<bool> addOobrPlaceToFavorites(oobrPlaceId) async {
    NetworkResponse response = await _api.addOobrPlaceToFavorites(oobrPlaceId);
    return response.data ?? false;
  }

  Future<List<BrPlaceScheduleModel>> getOobrPlaceSchedules(oobrPlaceId) async {
    NetworkResponse response = await _api.getOobrPlaceSchedules(oobrPlaceId);
    return response.data ?? [];
  }

  Future<List<BrPlaceMenu>> getOobrPlaceMenuList(oobrPlaceId) async {
    NetworkResponse response =
        await _api.getOobrPlaceMenuList(oobrPlaceId, appPrefs.languageCode);
    return response.data ?? [];
  }

  Future<List<PlaceMenuItemOption>> getOptionsForItem(itemId) async {
    NetworkResponse response =
        await _api.getOptionsForItem(itemId, appPrefs.languageCode);
    return response.data ?? [];
  }

  Future<List<PlaceMenuAllergens>> getAllergensForItem(itemId) async {
    NetworkResponse response =
        await _api.getAllergensForItem(itemId, appPrefs.languageCode);
    return response.data ?? [];
  }

  Future<List<PlaceMenuAllergens>> createOrderForOobrPlace(params) async {
    NetworkResponse response = await _api.createOrderForOobrPlace(params);
    return response.data ?? [];
  }

  Future<BrPlaceInviteModel?> getDetailOobrInvitations(oobrEventId) async {
    NetworkResponse response = await _api.getDetailOobrInvitations(oobrEventId);
    return response.data;
  }

  Future<bool> inviteContactsToOobrPlace(params) async {
    NetworkResponse response = await _api.inviteContactsToOobrPlace(params);
    return response.data ?? false;
  }

  Future<bool> answerOobrInvitation(params) async {
    NetworkResponse response = await _api.answerOobrInvitation(params);
    return response.data ?? false;
  }
}
